@@ -42,6 +42,8 @@ class CommunicationThread (threading.Thread):
         
         while True:
             image=self.qForCom.get()
+            if image == CLOSE_NOW:
+                break;
             #print('image')
             sendToApi(image, self.qForResult, SIGNATURE+'&passtoken='+passToken, ADDRESS)
             self.qForCom.task_done()
